@@ -67,7 +67,7 @@ CalculatePABinary <- function (dataMatrix, percentiles = 0.99, nReplicates = 200
                                                              as.integer(as.integer(x)-1))))
 
     result <- .Call(Cpolychoric, dataMatrixInt, isBinary,
-                    nReplicates, nearcor, new.env())
+                    nReplicates, sfsmisc::nearcor, new.env())
     datEigenValues <-sort(result[[1]], decreasing = TRUE)
   }
 
